Changelog

All notable changes to this project will be documented in this file.

[0.08] - 2026-04-29 (Security Fix: MED-6)

Security

[0.07] - 2026-04-29 (Security Fix: MED-1)

Security

[0.06] - 2026-04-29 (Security Fixes: MED-2, MED-3, MED-4, MED-5)

Security

Tests

[0.05] - 2026-04-29 (Security Fixes: HIGH-1 through HIGH-5)

Security

Tests

Documentation

[0.04] - 2026-04-29 (Security Fix: Open Redirect in Logout Endpoint)

Security

Added

Tests

Documentation

[0.03] - 2026-04-24 (FastCGI / Multi-Process Store Support)

Added

Changed

Tests

Documentation

[0.02] - 2026-04-16 (Bug Fixes & Integration Improvements)

Changed

Fixed

Documentation

[0.01] - 2026-04-10 (Initial Release)

Added

Core Implementation

OAuth 2.0 & OpenID Connect Features

Configuration

Security Features

Documentation

Tests

Example Application

Project Files

Implementation Details

Algorithm Support

Token Lifetimes

Standard Claims

Endpoints

Known Limitations

Requirements

Testing

All modules have unit test coverage. Run tests with:

prove -l t/

Future Roadmap

Author

Tim F. Rayner

License

This library is available under The Artistic License 2.0 (GPL Compatible). See LICENSE file for details.